==> aws-android-sdk-cognitoidentityprovider-2.2.19-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/CodeDeliveryDetailsTypeJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * Code Delivery Details Type JSON Unmarshaller
 */
public class CodeDeliveryDetailsTypeJsonUnmarshaller implements Unmarshaller<CodeDeliveryDetailsType, JsonUnmarshallerContext> {

    public CodeDeliveryDetailsType unmarshall(JsonUnmarshallerContext context) throws Exception {
        CodeDeliveryDetailsType codeDeliveryDetailsType = new CodeDeliveryDetailsType();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            
            if (name.equals("Destination")) {
                codeDeliveryDetailsType.setDestination(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            if (name.equals("DeliveryMedium")) {
                codeDeliveryDetailsType.setDeliveryMedium(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            if (name.equals("AttributeName")) {
                codeDeliveryDetailsType.setAttributeName(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            {
                reader.skipValue();
            }
            
        }
        reader.endObject();
        
        return codeDeliveryDetailsType;
    }

    private static CodeDeliveryDetailsTypeJsonUnmarshaller instance;
    public static CodeDeliveryDetailsTypeJsonUnmarshaller getInstance() {
        if (instance == null) instance = new CodeDeliveryDetailsTypeJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognitoidentityprovider-2.2.22-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/CodeDeliveryDetailsTypeJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO CodeDeliveryDetailsType
 */
class CodeDeliveryDetailsTypeJsonUnmarshaller implements
        Unmarshaller<CodeDeliveryDetailsType, JsonUnmarshallerContext> {

    public CodeDeliveryDetailsType unmarshall(JsonUnmarshallerContext context) throws Exception {
        CodeDeliveryDetailsType codeDeliveryDetailsType = new CodeDeliveryDetailsType();
        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("Destination")) {
                codeDeliveryDetailsType.setDestination(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("DeliveryMedium")) {
                codeDeliveryDetailsType.setDeliveryMedium(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("AttributeName")) {
                codeDeliveryDetailsType.setAttributeName(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return codeDeliveryDetailsType;
    }

    private static CodeDeliveryDetailsTypeJsonUnmarshaller instance;

    public static CodeDeliveryDetailsTypeJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CodeDeliveryDetailsTypeJsonUnmarshaller();
        return instance;
    }
}
